package com.landray.kmss.sys.attachment.transfer;

import org.hibernate.query.NativeQuery;
import org.hibernate.Session;
import java.util.List;
import com.landray.kmss.util.ResourceUtil;
import com.landray.kmss.sys.admin.transfer.model.SysAdminTransferTask;
import com.landray.kmss.sys.admin.transfer.constant.ISysAdminTransferConstant;
import com.landray.kmss.util.ArrayUtil;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.admin.transfer.service.ISysAdminTransferTaskService;
import com.landray.kmss.sys.admin.transfer.service.spring.SysAdminTransferResult;
import com.landray.kmss.sys.admin.transfer.service.spring.SysAdminTransferContext;
import com.landray.kmss.sys.admin.transfer.service.ISysAdminTransferTask;

public class SysAttLocationFieldTask extends SysAttTransferChecker implements ISysAdminTransferTask
{
    public SysAdminTransferResult run(final SysAdminTransferContext sysAdminTransferContext) {
        final String uuid = sysAdminTransferContext.getUUID();
        final ISysAdminTransferTaskService sysAdminTransferTaskService = (ISysAdminTransferTaskService)SpringBeanUtil.getBean("sysAdminTransferTaskService");
        final ISysAttMainCoreInnerService sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
        try {
            final HQLInfo info = new HQLInfo();
            info.setWhereBlock("sysAdminTransferTask.fdUuid=:uuid");
            info.setParameter("uuid", (Object)uuid);
            final List list = sysAdminTransferTaskService.getBaseDao().findValue(info);
            if (ArrayUtil.isEmpty(list)) {
                final String error = "sysAdminTransferTask记录不存在，uuid:" + uuid;
                return new SysAdminTransferResult(ISysAdminTransferConstant.TASK_RESULT_ERROR, error, (Throwable)new Exception(error));
            }
            final SysAdminTransferTask sysAdminTransferTask = list.get(0);
            if (sysAdminTransferTask.getFdStatus() == 1) {
                return SysAdminTransferResult.OK;
            }
            final Session session = sysAttMainService.getBaseDao().getHibernateSession();
            final String sql = "select count(fd_id) from sys_att_file f where f.fd_att_location='' or fd_att_location is null";
            final long count = ((Number)session.createNativeQuery(sql).uniqueResult()).longValue();
            if (count == 0L) {
                return SysAdminTransferResult.OK;
            }
            final String dialect = ResourceUtil.getKmssConfigString("hibernate.dialect");
            final StringBuilder updateSql = new StringBuilder();
            if (dialect.toLowerCase().indexOf("sqlserver") > -1) {
                updateSql.append("update f set f.fd_att_location=(").append("select min(m1.fd_att_location) from sys_att_main m1 where m1.fd_file_id=f.fd_id and m1.fd_att_location is not null").append(" group by m1.fd_file_id ) from sys_att_file f").append(" where exists(select fd_id from sys_att_main m where m.fd_file_id=f.fd_id and m.fd_att_location is not null) ").append("and f.fd_att_location='' or f.fd_att_location is null");
            }
            else {
                updateSql.append("update sys_att_file f set f.fd_att_location=(").append("select min(m1.fd_att_location) from sys_att_main m1 where m1.fd_file_id=f.fd_id and m1.fd_att_location is not null").append(" group by m1.fd_file_id ").append(") where exists(select fd_id from sys_att_main m where m.fd_file_id=f.fd_id and m.fd_att_location is not null) ").append("and f.fd_att_location='' or f.fd_att_location is null");
            }
            NativeQuery nativeQuery = session.createNativeQuery(updateSql.toString());
            nativeQuery.addSynchronizedQuerySpace("sys_att_file").executeUpdate();
            updateSql.setLength();
            if (dialect.toLowerCase().indexOf("sqlserver") > -1) {
                updateSql.append("update f set f.fd_att_location=(").append("select min(r1.fd_att_location) from sys_att_rtf_data r1 where r1.fd_file_id=f.fd_id and r1.fd_att_location is not null").append(" group by r1.fd_file_id ) from sys_att_file f").append(" where exists(select fd_id from sys_att_rtf_data r where r.fd_file_id=f.fd_id and r.fd_att_location is not null) ").append("and f.fd_att_location='' or f.fd_att_location is null");
            }
            else {
                updateSql.append("update sys_att_file f set f.fd_att_location=(").append("select min(r1.fd_att_location) from sys_att_rtf_data r1 where r1.fd_file_id=f.fd_id and r1.fd_att_location is not null").append(" group by r1.fd_file_id ").append(") where exists(select fd_id from sys_att_rtf_data r where r.fd_file_id=f.fd_id and r.fd_att_location is not null) ").append("and f.fd_att_location='' or f.fd_att_location is null");
            }
            nativeQuery = session.createNativeQuery(updateSql.toString());
            nativeQuery.addSynchronizedQuerySpace("sys_att_file").executeUpdate();
            nativeQuery = session.createNativeQuery("update sys_att_file set fd_att_location='server' where fd_att_location='' or fd_att_location is null");
            nativeQuery.addSynchronizedQuerySpace("sys_att_file").executeUpdate();
        }
        catch (final Exception e) {
            this.logger.error("附件表的location字段迁移异常", e);
            return new SysAdminTransferResult(ISysAdminTransferConstant.TASK_STATUS_NOT_RUNED, e.getLocalizedMessage(), (Throwable)e);
        }
        return SysAdminTransferResult.OK;
    }
}
